import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { CarouselItem } from './carousel-item';
import { CAROUSEL_ITEMS_INITIAL_COUNT } from './carousel.constants';

var getDefaultStyles = function getDefaultStyles(_ref) {
  var loading = _ref.loading;
  return {
    root: _objectSpread({
      "with": '100%',
      position: 'relative'
    }, loading && {
      pointerEvents: 'none',
      overflow: 'hidden'
    }),
    outerWrapper: {
      overflow: 'hidden'
    },
    wrapper: {
      width: '100%',
      overflowX: 'auto',
      overflowY: 'hidden',
      WebkitOverflowScrolling: 'touch',
      scrollSnapType: 'x mandatory',
      paddingBottom: '24px',
      marginBottom: '-24px'
    },
    items: {
      display: 'inline-flex',
      // set the flex container 100% to allow items to stretch full width
      width: '100%'
    },
    item: {
      flex: '0 0 auto'
    }
  };
};

export var Carousel = function Carousel(props) {
  var className = props.className,
      getStyles = props.getStyles,
      loading = props.loading,
      wrapperRef = props.wrapperRef,
      addItem = props.addItem,
      removeItem = props.removeItem,
      itemsVisibility = props.itemsVisibility,
      itemIntersectionObserverEnabled = props.itemIntersectionObserverEnabled,
      hasPrevItems = props.hasPrevItems,
      hasNextItems = props.hasNextItems,
      showItem = props.showItem,
      showNextItems = props.showNextItems,
      showPrevItems = props.showPrevItems,
      renderNavigation = props.renderNavigation,
      lazyRender = props.lazyRender,
      inViewport = props.inViewport,
      items = props.items;
  var defaultStyles = getDefaultStyles({
    loading: loading
  });
  var styles = getStyles(defaultStyles, {
    loading: loading
  }); // Use enhanced (IntersectionObserver) item component when in viewport prop is enabled

  var ItemComponent = itemIntersectionObserverEnabled ? CarouselItem : function (_ref2) {
    var itemChild = _ref2.children,
        itemStyle = _ref2.style,
        restItemProps = _objectWithoutProperties(_ref2, ["children", "style"]);

    return React.cloneElement(itemChild, _objectSpread({
      style: _objectSpread({}, itemStyle, {}, itemChild.props.style)
    }, restItemProps));
  }; // When lazyRender, render just the minimum amount initially and the rest when in viewport

  var childItems = lazyRender && !inViewport ? items.slice(0, CAROUSEL_ITEMS_INITIAL_COUNT) : items;
  return React.createElement("div", {
    className: className,
    style: styles.root
  }, React.createElement("div", {
    style: styles.outerWrapper
  }, React.createElement("div", {
    style: styles.wrapper,
    ref: wrapperRef
  }, React.createElement("div", {
    style: styles.items
  }, childItems.map(function (item, index) {
    var key = index;
    return React.createElement(ItemComponent, {
      key: key,
      index: index,
      isVisible: itemsVisibility[index],
      style: styles.item,
      loading: loading,
      addItem: addItem,
      removeItem: removeItem
    }, item);
  })))), renderNavigation({
    hasPrevItems: hasPrevItems,
    hasNextItems: hasNextItems,
    showItem: showItem,
    showPrevItems: showPrevItems,
    showNextItems: showNextItems,
    itemsVisibility: itemsVisibility
  }));
};
Carousel.defaultProps = {
  className: '',
  loading: false,
  getStyles: function getStyles(styles) {
    return styles;
  },
  // snapScrolling: false,
  renderNavigation: function renderNavigation() {
    return null;
  }
};
Carousel.propTypes = {
  /** Adopted child class name */
  className: PropTypes.string,

  /** Get styles render prop */
  getStyles: PropTypes.func,

  /** Loading flag */
  loading: PropTypes.bool,

  /** snap scrolling flag */
  // snapScrolling: PropTypes.bool,

  /** scrollIntoView operation is in progress */
  // hasItemsScrollingIntoView: PropTypes.bool.isRequired,

  /** Carousel wrapper ref */
  wrapperRef: PropTypes.object.isRequired,
  // eslint-disable-line react/forbid-prop-types

  /** Carousel itemsVisibility addItem handler */
  addItem: PropTypes.func.isRequired,

  /** Carousel itemsVisibility removeItem handler */
  removeItem: PropTypes.func.isRequired,

  /** Navigation render prop */
  renderNavigation: PropTypes.func,

  /** Items visibility data */
  itemsVisibility: PropTypes.arrayOf(PropTypes.bool).isRequired,

  /** itemIntersectionObserverEnabled flag */
  itemIntersectionObserverEnabled: PropTypes.bool.isRequired,

  /** Carousel prev itemsVisibility flag */
  hasPrevItems: PropTypes.bool.isRequired,

  /** Carousel next itemsVisibility flag */
  hasNextItems: PropTypes.bool.isRequired,

  /** Carousel show item handler */
  showItem: PropTypes.func.isRequired,

  /** Carousel show prev itemsVisibility handler */
  showPrevItems: PropTypes.func.isRequired,

  /** Carousel show next itemsVisibility handler */
  showNextItems: PropTypes.func.isRequired,

  /** Carousel lazyRender flag */
  lazyRender: PropTypes.bool.isRequired,

  /** Carouse inViewport flag */
  inViewport: PropTypes.bool.isRequired,

  /** Items content */
  items: PropTypes.array.isRequired // eslint-disable-line react/forbid-prop-types

};