import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

/* global window */
import React, { useEffect, useState } from 'react';
import { storiesOf } from '@storybook/react';
import { Carousel } from './';
var ITEMS = Array(16).fill('');

var ItemComponent = function ItemComponent(props, ref) {
  var style = props.style,
      index = props.index,
      _props$isVisible = props.isVisible,
      isVisible = _props$isVisible === void 0 ? true : _props$isVisible,
      loading = props.loading,
      restProps = _objectWithoutProperties(props, ["style", "index", "isVisible", "loading"]);

  return React.createElement("div", _extends({
    style: _objectSpread({
      background: loading ? '#eee' : 'linear-gradient(-20deg, lightpink, skyblue)',
      color: '#fff',
      fontWeight: 'bold',
      width: '200px',
      height: '240px',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
      marginLeft: index > 0 ? '12px' : 0
    }, !isVisible && {
      opacity: 0.5,
      pointerEvents: 'none'
    }, {}, style),
    ref: ref
  }, restProps), index + 1);
};

var Item = React.forwardRef(ItemComponent);
var stories = storiesOf('Carousel', module);
stories.addDecorator(function (storyFn) {
  return React.createElement("div", {
    style: {
      padding: '24px'
    }
  }, storyFn());
});
stories.add('default', function () {
  return React.createElement(Carousel, {
    items: ITEMS.map(function (item, index) {
      return React.createElement(Item, {
        index: index
      });
    })
  });
});
stories.add('loading', function () {
  return React.createElement(Carousel, {
    loading: true,
    items: Array(5).fill('').map(function (item, index) {
      return React.createElement(Item, {
        index: index
      });
    })
  });
});
stories.add('with full width item', function () {
  return React.createElement(Carousel, {
    items: ITEMS.map(function (item, index) {
      return React.createElement(Item, {
        index: index,
        style: {
          width: '100%'
        }
      });
    })
  });
});
stories.add('with variable width item', function () {
  return React.createElement(Carousel, {
    items: ITEMS.map(function (item, index) {
      return React.createElement(Item, {
        index: index,
        style: {
          width: "".concat((index + 1) * 5, "%")
        }
      });
    })
  });
});
stories.add('with custom styles', function () {
  return React.createElement(Carousel, {
    items: ITEMS.map(function (item, index) {
      return React.createElement(Item, {
        index: index
      });
    }),
    getStyles: function getStyles(defaultStyles) {
      return _objectSpread({}, defaultStyles, {
        root: _objectSpread({}, defaultStyles.root, {
          boxShadow: '0 0 10px pink'
        }),
        wrapper: _objectSpread({}, defaultStyles.wrapper, {
          background: 'lightpink'
        })
      });
    }
  });
});

var CarouselWithAsyncData = function CarouselWithAsyncData() {
  var _useState = useState(true),
      _useState2 = _slicedToArray(_useState, 2),
      loading = _useState2[0],
      setLoading = _useState2[1];

  var _useState3 = useState(Array(5).fill('')),
      _useState4 = _slicedToArray(_useState3, 2),
      items = _useState4[0],
      setItems = _useState4[1];

  useEffect(function () {
    var fetchData = window.setTimeout(function () {
      setLoading(false);
      setItems(Array(20).fill(''));
    }, 3000);
    return function () {
      window.clearTimeout(fetchData);
    };
  }, []);
  return React.createElement(React.Fragment, null, React.createElement("p", null, "Loading: ".concat(JSON.stringify(loading))), React.createElement(Carousel, {
    loading: loading,
    items: items.map(function (item, index) {
      return React.createElement(Item, {
        index: index
      });
    })
  }));
};

stories.add('with async data', function () {
  return React.createElement(CarouselWithAsyncData, null);
});
stories.add('with item intersection observer', function () {
  return React.createElement(Carousel, {
    itemIntersectionObserverEnabled: true,
    items: ITEMS.map(function (item, index) {
      return React.createElement(Item, {
        index: index
      });
    })
  });
});
stories.add('with navigation', function () {
  return React.createElement(Carousel, {
    itemIntersectionObserverEnabled: true,
    items: ITEMS.map(function (item, index) {
      return React.createElement(Item, {
        index: index
      });
    }),
    renderNavigation: function renderNavigation(_ref) {
      var hasPrevItems = _ref.hasPrevItems,
          hasNextItems = _ref.hasNextItems,
          showPrevItems = _ref.showPrevItems,
          showNextItems = _ref.showNextItems;
      return React.createElement("nav", {
        style: {
          position: 'absolute',
          left: 0,
          right: 0,
          top: '50%'
        }
      }, React.createElement("button", {
        type: "button",
        style: {
          position: 'absolute',
          left: 0,
          top: '50%'
        },
        onClick: showPrevItems,
        disabled: !hasPrevItems
      }, "Previous"), React.createElement("button", {
        type: "button",
        style: {
          position: 'absolute',
          right: 0,
          top: '50%'
        },
        onClick: showNextItems,
        disabled: !hasNextItems
      }, "Next"));
    }
  });
});
stories.add('with pagination', function () {
  return React.createElement(Carousel, {
    itemIntersectionObserverEnabled: true,
    items: ITEMS.map(function (item, index) {
      return React.createElement(Item, {
        index: index
      });
    }),
    renderNavigation: function renderNavigation(_ref2) {
      var itemsVisibility = _ref2.itemsVisibility,
          showItem = _ref2.showItem;
      return React.createElement("nav", {
        style: {
          padding: '12px',
          textAlign: 'center'
        }
      }, itemsVisibility.map(function (isVisible, index) {
        return React.createElement("button", {
          type: "button",
          onClick: function onClick() {
            return showItem(index);
          }
        }, index + 1);
      }));
    }
  });
});
stories.add('with lazyRender', function () {
  return React.createElement(React.Fragment, null, React.createElement("div", {
    style: {
      height: '100vh'
    }
  }, React.createElement("p", null, "Scroll down to test lazyRender")), React.createElement(Carousel, {
    lazyRender: true,
    items: ITEMS.map(function (item, index) {
      return React.createElement(Item, {
        index: index
      });
    })
  }));
});